@@ -145,3 +145,19 @@ pub type RawCpuid = u32;
 
 #[cfg(not(target_os = "wasi"))]
 pub type RawUname = libc::utsname;
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+pub type RawCpuSet = libc::cpu_set_t;
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+pub const CPU_SETSIZE: usize = libc::CPU_SETSIZE as usize;
