@@ -90,10 +90,17 @@ use super::offset::{libc_fstat, libc_fstatat, libc_lseek, libc_off_t, libc_pread
 use super::offset::{libc_preadv2, libc_pwritev2};
 #[cfg(not(any(target_os = "fuchsia", target_os = "redox", target_os = "wasi")))]
 use super::offset::{libc_rlimit, LIBC_RLIM_INFINITY};
-#[cfg(not(target_os = "wasi"))]
-use super::process::RawUname;
 #[cfg(not(any(target_os = "fuchsia", target_os = "redox", target_os = "wasi")))]
 use super::process::Resource;
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+use super::process::{RawCpuSet, CPU_SETSIZE};
+#[cfg(not(target_os = "wasi"))]
+use super::process::{RawPid, RawUname};
 #[cfg(target_os = "linux")]
 use super::rand::GetRandomFlags;
 use super::time::Timespec;
@@ -104,20 +111,20 @@ use crate::process::Rlimit;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use crate::process::{Cpuid, MembarrierCommand, MembarrierQuery};
 #[cfg(not(target_os = "wasi"))]
-use crate::process::{Gid, Pid, Uid};
+use crate::process::{Gid, Pid, Uid, WaitOptions, WaitStatus};
 use errno::errno;
 use io_lifetimes::{AsFd, BorrowedFd};
 use libc::{c_int, c_void};
 use std::cmp::min;
 use std::convert::TryInto;
 use std::ffi::CStr;
+#[cfg(any(target_os = "ios", target_os = "macos"))]
+use std::ffi::CString;
 use std::io::{IoSlice, IoSliceMut, SeekFrom};
 #[cfg(target_os = "linux")]
 use std::mem::transmute;
 use std::mem::{size_of, MaybeUninit};
 use std::net::{SocketAddrV4, SocketAddrV6};
-#[cfg(any(target_os = "ios", target_os = "macos"))]
-use std::os::unix::ffi::OsStringExt;
 #[cfg(not(any(target_os = "redox", target_os = "wasi",)))]
 use std::ptr::null_mut;
 #[cfg(not(any(target_os = "redox", target_env = "newlib")))]
@@ -126,7 +133,6 @@ use std::sync::atomic::{AtomicUsize, Ordering};
 use {
     super::conv::nonnegative_ret,
     super::fs::{copyfile_state_t, CloneFlags, CopyfileFlags},
-    std::path::PathBuf,
 };
 #[cfg(not(target_os = "redox"))]
 use {
@@ -2049,7 +2055,7 @@ pub(crate) unsafe fn copyfile_state_get(
 }
 
 #[cfg(any(target_os = "ios", target_os = "macos"))]
-pub(crate) fn getpath(fd: BorrowedFd<'_>) -> io::Result<PathBuf> {
+pub(crate) fn getpath(fd: BorrowedFd<'_>) -> io::Result<CString> {
     // The use of PATH_MAX is generally not encouraged, but it
     // is inevitable in this case because macOS defines `fcntl` with
     // `F_GETPATH` in terms of `MAXPATHLEN`, and there are no
@@ -2071,9 +2077,9 @@ pub(crate) fn getpath(fd: BorrowedFd<'_>) -> io::Result<PathBuf> {
     }
 
     let l = buf.iter().position(|&c| c == 0).unwrap();
-    buf.truncate(l as usize);
-    buf.shrink_to_fit();
-    Ok(PathBuf::from(std::ffi::OsString::from_vec(buf)))
+    buf.truncate(l);
+    buf.shrink_to(l + 1);
+    Ok(CString::new(buf).unwrap())
 }
 
 #[cfg(any(target_os = "ios", target_os = "macos"))]
@@ -2183,6 +2189,113 @@ pub(crate) fn gettid() -> Pid {
     }
 }
 
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[allow(non_snake_case)]
+#[inline]
+pub(crate) fn CPU_SET(cpu: usize, cpuset: &mut RawCpuSet) {
+    if cpu >= CPU_SETSIZE {
+        panic!(
+            "cpu out of bounds: the cpu max is {} but the cpu is {}",
+            CPU_SETSIZE, cpu
+        )
+    }
+    unsafe { libc::CPU_SET(cpu, cpuset) }
+}
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[allow(non_snake_case)]
+#[inline]
+pub(crate) fn CPU_ZERO(cpuset: &mut RawCpuSet) {
+    unsafe { libc::CPU_ZERO(cpuset) }
+}
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[allow(non_snake_case)]
+#[inline]
+pub(crate) fn CPU_CLR(cpu: usize, cpuset: &mut RawCpuSet) {
+    if cpu >= CPU_SETSIZE {
+        panic!(
+            "cpu out of bounds: the cpu max is {} but the cpu is {}",
+            CPU_SETSIZE, cpu
+        )
+    }
+    unsafe { libc::CPU_CLR(cpu, cpuset) }
+}
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[allow(non_snake_case)]
+#[inline]
+pub(crate) fn CPU_ISSET(cpu: usize, cpuset: &RawCpuSet) -> bool {
+    if cpu >= CPU_SETSIZE {
+        panic!(
+            "cpu out of bounds: the cpu max is {} but the cpu is {}",
+            CPU_SETSIZE, cpu
+        )
+    }
+    unsafe { libc::CPU_ISSET(cpu, cpuset) }
+}
+
+#[cfg(any(target_os = "linux"))]
+#[allow(non_snake_case)]
+#[inline]
+pub fn CPU_COUNT(cpuset: &RawCpuSet) -> u32 {
+    unsafe { libc::CPU_COUNT(cpuset).try_into().unwrap() }
+}
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[inline]
+pub(crate) fn sched_getaffinity(pid: Pid, cpuset: &mut RawCpuSet) -> io::Result<()> {
+    unsafe {
+        ret(libc::sched_getaffinity(
+            pid.as_raw() as _,
+            std::mem::size_of::<RawCpuSet>(),
+            cpuset,
+        ))
+    }
+}
+
+#[cfg(any(
+    target_os = "linux",
+    target_os = "android",
+    target_os = "fuchsia",
+    target_os = "dragonfly"
+))]
+#[inline]
+pub(crate) fn sched_setaffinity(pid: Pid, cpuset: &RawCpuSet) -> io::Result<()> {
+    unsafe {
+        ret(libc::sched_setaffinity(
+            pid.as_raw() as _,
+            std::mem::size_of::<RawCpuSet>(),
+            cpuset,
+        ))
+    }
+}
+
 #[inline]
 pub(crate) fn sched_yield() {
     unsafe {
@@ -2305,6 +2418,20 @@ pub(crate) fn getrlimit(limit: Resource) -> Rlimit {
     }
 }
 
+#[cfg(not(target_os = "wasi"))]
+#[inline]
+pub fn waitpid(pid: RawPid, waitopts: WaitOptions) -> io::Result<Option<(Pid, WaitStatus)>> {
+    unsafe {
+        let mut status: c_int = 0;
+        let pid = ret_c_int(libc::waitpid(pid as _, &mut status, waitopts.bits() as _))?;
+        if pid == 0 {
+            Ok(None)
+        } else {
+            Ok(Some((Pid::from_raw(pid), WaitStatus::new(status as _))))
+        }
+    }
+}
+
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 pub(crate) mod sockopt {
     use crate::net::sockopt::Timeout;
