@@ -12,21 +12,19 @@ fn tmpdir() -> TempDir {
 #[cfg(not(target_os = "macos"))]
 #[test]
 fn test_changing_working_directory() {
-    use std::ffi::OsString;
-
     let tmpdir = tmpdir();
 
-    let orig_cwd = rsix::process::getcwd(OsString::new()).expect("get the cwd");
+    let orig_cwd = rsix::process::getcwd(Vec::new()).expect("get the cwd");
     let orig_fd_cwd = rsix::fs::openat(&rsix::fs::cwd(), ".", OFlags::RDONLY, Mode::empty())
         .expect("get a fd for the current directory");
 
     rsix::process::chdir(tmpdir.path()).expect("changing dir to the tmp");
-    let ch1_cwd = rsix::process::getcwd(OsString::new()).expect("get the cwd");
+    let ch1_cwd = rsix::process::getcwd(Vec::new()).expect("get the cwd");
 
     assert_ne!(orig_cwd, ch1_cwd, "The cwd hasn't changed!");
     assert_eq!(
-        ch1_cwd,
-        tmpdir.path(),
+        ch1_cwd.to_string_lossy(),
+        tmpdir.path().to_string_lossy(),
         "The cwd is not the same as the tmpdir"
     );
 
